# lingo - payment and billing system
# Copyright (C) 2023  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import get_object_or_404
from rest_framework.views import APIView

from lingo.agendas.models import Agenda
from lingo.api.utils import Response


class AgendaCheckTypeList(APIView):
    permission_classes = ()

    def get(self, request, agenda_identifier=None, format=None):
        agenda = get_object_or_404(Agenda, slug=agenda_identifier)

        check_types = []
        if agenda.check_type_group:
            check_types = [
                {
                    'id': x.slug,
                    'text': x.label,
                    'kind': x.kind,
                    'unexpected_presence': bool(agenda.check_type_group.unexpected_presence == x),
                }
                for x in agenda.check_type_group.check_types.filter(disabled=False)
            ]
        return Response({'data': check_types})


agenda_check_type_list = AgendaCheckTypeList.as_view()
