import django_webtest
import pytest
from django.contrib.auth.models import User
from django.core.cache import cache


@pytest.fixture(autouse=True)
def media(settings, tmpdir):
    settings.MEDIA_ROOT = str(tmpdir.mkdir('media'))


@pytest.fixture
def app(request):
    wtm = django_webtest.WebTestMixin()
    wtm._patch_settings()
    request.addfinalizer(wtm._unpatch_settings)
    cache.clear()
    return django_webtest.DjangoTestApp()


@pytest.fixture
def simple_user():
    user = User.objects.create_user('user', password='user')
    user.saml_identifiers.create(name_id='ab' * 16)
    return user


@pytest.fixture
def admin_user():
    return User.objects.create_superuser('admin', email=None, password='admin')


@pytest.fixture
def nocache(settings):
    settings.CACHES = {
        'default': {
            'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
        }
    }
